#!/usr/bin/env python3

"""_TEMPLATE_PROJ_ --- tagline of your project"""

# Copyright (C) 2016 _TEMPLATE_AUTHOR_

# Author: _TEMPLATE_AUTHOR_

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

# "${DATADIR}" will be replaced with the data directory
# (i.e. /usr/share/_TEMPLATE_PROJ_) by autotools
# Use _TEMPLATE_PROJ__DATA in Makefile.am to select files to install.

import argparse
import sys
# setup sane logging. It tells you why, where and when something was
# logged, so you can jump to the source line right away.
import logging
logging.basicConfig(level=logging.WARNING,
                    format=' [%(levelname)-7s] (%(asctime)s) %(filename)s::%(lineno)d %(message)s',
                    datefmt='%Y-%m-%d %H:%M:%S')

parser = argparse.ArgumentParser(description=__doc__.splitlines()[0])
parser.add_argument("--debug", action="store_true",
                    help="Set log level to debug")
parser.add_argument("--info", action="store_true",
                    help="Set log level to info")
parser.add_argument("--test", action="store_true",
                    help="Run tests")


# output test results as base60 number (for aestitics)
def numtosxg(n):
    """
    >>> numtosxg(5)
    '5'
    >>> numtosxg(10)
    'A'
    """
    CHARACTERS = '0123456789ABCDEFGHJKLMNPQRSTUVWXYZ_abcdefghijkmnopqrstuvwxyz'
    s = ''
    if not isinstance(n, int) or n == 0:
        return '0'
    while n > 0:
        n, i = divmod(n, 60)
        s = CHARACTERS[i] + s
    return s

# run doctests. This function could also contain some custom test code.
def _test():
    """
    >>> import sys
    >>> handlers = logging.getLogger().handlers # ensure that we log to stdout
    >>> logging.getLogger().handlers = []
    >>> logging.getLogger().addHandler(logging.StreamHandler(stream=sys.stdout))
    >>> logging.warn("test logging")
    test logging
    >>> logging.getLogger().handlers = handlers
    """
    from doctest import testmod
    return testmod()


# add a commandline switch to increase the log-level when running this
# script standalone. --test should run the tests.
if __name__ == "__main__":
    args = parser.parse_args()
    if args.debug:
        logging.getLogger().setLevel(logging.DEBUG)
    elif args.info:
        logging.getLogger().setLevel(logging.INFO)
    if args.test:
        tests = _test()
        if not tests.failed:
            print("^_^ ({})".format(numtosxg(tests.attempted)))
        else:
            print("☹"*tests.failed)
        if tests.failed:
            sys.exit(1)
